@@ -3,14 +3,14 @@
 #' @inheritParams default_doc_internal
 #' @keywords internal
 get_predict_model <- function(predict_model, model) {
-  # Checks that predict_model is a proper function (R + py)
-  # Extracts natively supported functions for predict_model if exists and not passed (R only)
-  # Checks that predict_model provide the right output format (R and py)
-  # Returns the predict_model to use subsequently (R only)
+  # Check that predict_model is a proper function (R + Python)
+  # Extract natively supported functions for predict_model if they exist and are not passed (R only)
+  # Check that predict_model provides the right output format (R and Python)
+  # Return the predict_model to use subsequently (R only)
 
   model_class0 <- class(model)[1]
 
-  # checks predict_model
+  # Check predict_model
   if (!(is.function(predict_model)) &&
     !(is.null(predict_model))) {
     cli::cli_abort("`predict_model` must be NULL or a function.")
@@ -18,7 +18,7 @@ get_predict_model <- function(predict_model, model) {
 
   supported_models <- get_supported_models()
 
-  # Get native predict_model if not passed and exists
+  # Get native predict_model if not passed and available
   if (is.null(predict_model)) {
     native_func_available <- supported_models[predict_model == TRUE, model_class0 %in% model_class]
     if (native_func_available) {
@@ -26,8 +26,8 @@ get_predict_model <- function(predict_model, model) {
     } else {
       cli::cli_abort(
         paste0(
-          "You passed a model to {.fn shapr::explain} which is not natively supported, ",
-          "and did not supply the 'predict_model' function to {.fn shapr::explain}. ",
+          "You passed a model to {.fn shapr::explain} that is not natively supported ",
+          "and did not supply a 'predict_model' function to {.fn shapr::explain}. ",
           "See the documentation of {.fn shapr::explain} or the ",
           "{.vignette shapr::general_usage} vignette for more information on how to run shapr with custom models."
         )
@@ -42,7 +42,7 @@ get_predict_model <- function(predict_model, model) {
 #' @inheritParams default_doc_internal
 #' @keywords internal
 test_predict_model <- function(x_test, predict_model, model, internal) {
-  # Tests prediction with some data
+  # Test prediction with sample data
   if (!is.null(internal$parameters$type) && internal$parameters$type == "forecast") {
     tmp <- tryCatch(predict_model(
       x = model,
@@ -62,7 +62,7 @@ test_predict_model <- function(x_test, predict_model, model, internal) {
   }
   if (class(tmp)[1] == "error") {
     cli::cli_abort(paste0(
-      "The predict_model function of class `", class(model), "` is invalid. ",
+      "The predict_model function for class `", class(model), "` is invalid. ",
       "See the 'Advanced usage' section of ",
       "{.vignette shapr::general_usage} vignette ",
       "for more information on running shapr with custom models. ",
@@ -75,7 +75,7 @@ test_predict_model <- function(x_test, predict_model, model, internal) {
     (length(tmp) == 2 || (!is.null(dim(tmp)) && nrow(tmp) == 2 && ncol(tmp) == internal$parameters$output_size)))) {
     cli::cli_abort(
       paste0(
-        "The predict_model function of class `", class(model),
+        "The predict_model function for class `", class(model),
         "` does not return a numeric output of the desired length ",
         "for single output models or a data.table of the correct ",
         "dimensions for a multiple output model. ",
