@@ -2,7 +2,7 @@
 #' @export
 predict_model.xgb.Booster <- function(x, newdata, ...) {
   if (!requireNamespace("xgboost", quietly = TRUE)) {
-    cli::cli_abort("The {.pkg xgboost} package is required for predicting `xgboost` models")
+    cli::cli_abort("The {.pkg xgboost} package is required for predicting `xgboost` models.")
   }
 
   predict(x, as.matrix(newdata))
@@ -31,8 +31,8 @@ model_checker.xgb.Booster <- function(x) {
   ) {
     cli::cli_abort(
       paste0(
-        "We currently don't support multi-classification using `xgboost`, i.e. ",
-        "where `num_class` is greater than 2."
+        "We currently do not support multiclass classification using `xgboost`, i.e., ",
+        "when `num_class` is greater than 2."
       )
     )
   }
@@ -40,9 +40,9 @@ model_checker.xgb.Booster <- function(x) {
   if (!is.null(x$params$objective) && x$params$objective == "reg:logistic") {
     cli::cli_abort(
       paste0(
-        "We currently don't support standard classification, which predicts the class directly. ",
-        "To train an `xgboost` model predicting the class probabilities, you'll need to change ",
-        "the objective to `binary:logistic`"
+        "We currently do not support standard classification, which predicts the class directly. ",
+        "To train an `xgboost` model that predicts class probabilities, change ",
+        "the objective to `binary:logistic`."
       )
     )
   }
