@@ -21,13 +21,13 @@ NULL
 "_PACKAGE"
 
 #' Auxiliary function for the vignettes
-#' @description Function that question if the main and vaeac vignette has been built using the
-#' `rebuild-long-running-vignette.R` function.
-#' This is only useful when using devtools to release `shapr` to cran.
+#' @description Ask whether the vignettes have been built using the
+#' `rebuild-long-running-vignette.R` script.
+#' This is only useful when using devtools to release `shapr` to CRAN.
 #' See [devtools::release()] for more information.
 #' @keywords internal
 release_questions <- function() {
   c(paste0(
-    "Did you re-build the vignettes using `rebuild-long-running-vignette.R`?"
+    "Did you rebuild the vignettes using `rebuild-long-running-vignette.R`?"
   ))
 }
