@@ -185,6 +185,8 @@ test_that("erroneous input: `min_n_batches`", {
 })
 
 test_that("different n_batches gives same/different shapley values for different approaches", {
+  skip_if_not_installed("party")
+
   # approach "empirical" is seed independent
   explain.empirical_n_batches_5 <- explain(
     testing = TRUE,
@@ -410,3 +412,40 @@ test_that("output_lm_numeric_independence_keep_samp_for_vS", {
 
   expect_false(is.null(out$internal$output$dt_samp_for_vS))
 })
+
+
+test_that("output_verbose_suppressMessages", {
+  # Test that the verbose argument works with suppressMessages
+  expect_silent({
+    suppressMessages({
+      ex <- explain(
+        testing = TRUE,
+        model = model_lm_numeric,
+        x_explain = x_explain_numeric,
+        x_train = x_train_numeric,
+        approach = "gaussian",
+        phi0 = p0,
+        seed = 1,
+        iterative = TRUE,
+        verbose = c("basic", "convergence", "shapley", "vS_details")
+      )
+    })
+  })
+})
+
+test_that("output_verbose_NULL", {
+  # Test that the verbose argument works with suppressMessages
+  expect_silent({
+    ex <- explain(
+      testing = TRUE,
+      model = model_lm_numeric,
+      x_explain = x_explain_numeric,
+      x_train = x_train_numeric,
+      approach = "gaussian",
+      phi0 = p0,
+      seed = 1,
+      iterative = TRUE,
+      verbose = NULL
+    )
+  })
+})
